summaryrefslogtreecommitdiff
path: root/src/eval.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/eval.c')
-rwxr-xr-xsrc/eval.c15
1 files changed, 12 insertions, 3 deletions
diff --git a/src/eval.c b/src/eval.c
index 63fd301..06e6bc7 100755
--- a/src/eval.c
+++ b/src/eval.c
@@ -4386,7 +4386,7 @@ Return value:
FLAG
-EvalPasserRaces(IN OUT POSITION *pos,
+_EvalPasserRacesAgainstLoneKings(IN OUT POSITION *pos,
IN PAWN_HASH_ENTRY *pHash)
/**
@@ -4427,7 +4427,7 @@ Return value:
// Both deferred past the no-passer early return above -- no need to
// pay for this on the common case (most positions have no passer at
// all, and EvalPasserRaces itself is only even called when a side
// is down to a bare king, so this function runs unconditionally in
// the pre-lazy-exit segment whenever that's true).
uRacerDist[BLACK] = 99;
@@ -4962,6 +4962,15 @@ Return value:
+void
+InitEval(void)
+{
+ // No-op placeholder: nothing to initialize until the
+ // ROOK_FULL_HALF_OPEN_BONUS static cache (from the eval.c overhaul,
+ // not yet re-applied here -- see stash) exists.
+}
+
+
SCORE
Eval(IN SEARCHER_THREAD_CONTEXT *ctx,
IN SCORE iAlpha,
@@ -5074,7 +5083,7 @@ Return value:
if ((pos->uNonPawnCount[WHITE][0] == 1) ||
(pos->uNonPawnCount[BLACK][0] == 1))
{
- (void)EvalPasserRaces(pos, pHash);
+ (void)_EvalPasserRacesAgainstLoneKings(pos, pHash);
#ifdef EVAL_DUMP
Trace("After passer races:\n%d\t\t%d\n", pos->iScore[WHITE],
pos->iScore[BLACK]);
@@ -4427,7 +4427,7 @@ Return value:
// Both deferred past the no-passer early return above -- no need to
// pay for this on the common case (most positions have no passer at
- // all, and EvalPasserRaces itself is only even called when a side
+ // all, and _EvalPasserRacesAgainstLoneKings itself is only even called when a side
// is down to a bare king, so this function runs unconditionally in
// the pre-lazy-exit segment whenever that's true).